var map;
var mapMarker;
var formPrefix;

function loadGoogleMaps() {

	var mapElement = document.getElementById('admin-map');
	var src = `https://maps.googleapis.com/maps/api/js?key=${mapElement.dataset.key}&callback=initMap`;
	if (document.querySelectorAll(`script[src="${src}"]`).length) {
		initMap();
	} else {
		var googleMapsLibrary = document.createElement('script');
		googleMapsLibrary.src = src;
		googleMapsLibrary.defer = true;
		document.head.appendChild(googleMapsLibrary);
	}


}


window.initMap = function () {


	formPrefix = document.getElementById('Form_ItemEditForm_Latitude') ? 'Form_ItemEditForm_' : 'Form_EditForm_';

    var latField = document.getElementById(formPrefix + 'Latitude');
    var lngField = document.getElementById(formPrefix + 'Longitude');
    var zoomLevel = 14;

    if (!latField.value || !lngField.value) {
        latField.value = -25.801516;
        lngField.value = 134.059830;
        zoomLevel = 4;
    }

    var center = new google.maps.LatLng(latField.value, lngField.value);
    map = new google.maps.Map(document.getElementById('admin-map'), {
        center: center,
        zoom: zoomLevel,
        scrollwheel: false
    });

    mapMarker = new google.maps.Marker({
        map: map,
        position: center,
        draggable: true
    });
    mapMarker.addListener('dragend', function() {
        setLatLng(
            mapMarker.getPosition().lat(),
            mapMarker.getPosition().lng()
        );
    });
}


function setCoords() {
    var geoCoder = new google.maps.Geocoder();
    geoCoder.geocode({address: getAddress()}, function(results, status) {
        if (status == 'OK') {
            setMarker(
                results[0].geometry.location.lat(),
                results[0].geometry.location.lng()
            );
            setLatLng(
                results[0].geometry.location.lat(),
                results[0].geometry.location.lng()
            );
        } else {
            alert('Geocode was not successful: ' + status);
        }
    });
}


function setMarker(lat, lng) {
    var center = new google.maps.LatLng(lat, lng);
    mapMarker.setPosition(center);
    map.setCenter(center);
    map.setZoom(14);
}


function setLatLng(lat, lng) {
    document.getElementById(formPrefix + 'Latitude').value = lat;
    document.getElementById(formPrefix + 'Longitude').value = lng;
}


function getAddress() {
    var fields = [
        document.getElementById(formPrefix + 'Address1').value,
        document.getElementById(formPrefix + 'Address2').value,
        document.getElementById(formPrefix + 'City').value,
        document.getElementById(formPrefix + 'Postcode').value,
        document.getElementById(formPrefix + 'State').value,
        document.getElementById(formPrefix + 'Country').value
    ];
    var address = '';
    for (var i = 0; i < fields.length; i++) {
        if (fields[i]) {
            address += fields[i] + ' ';
        }
    }
    return address;
}


(function ($) {
    $(document).ready(function() {

        jQuery('.cms-container').on('click', '.location-tab-with-map .ui-tabs-anchor', function () {
			loadGoogleMaps();
        });

        jQuery('.cms-container').on('click', '#set-map-coords', function () {
            setCoords();
        });

        $.entwine(function($) {
            $("div.admin-google-map").entwine({
                onmatch: function() {
					loadGoogleMaps();
                    this._super();
                }
            });
        });


    });
})(jQuery);
