<?php

namespace Fastrack\Location;


use SilverStripe\Core\Environment;
use SilverStripe\Forms\LiteralField;
use SilverStripe\SiteConfig\SiteConfig;
use SilverStripe\View\Requirements;

class GoogleMapField extends LiteralField
{

	private $mapOptions = [
		'width' => '100%',
		'height' => '500px',
		'margin' => '10px',
		'heading' => 'Map',
	];

	private $key = '';

	public function __construct($name, $options = [])
	{
		$this->key = SiteConfig::current_site_config()->getField('GoogleMapAPIKey');
		foreach ($options as $key => $value) {
			$this->mapOptions[$key] = $value;
		}
		parent::__construct($name, $this->buildContent());
	}


	private function buildContent()
	{
		$content = "";
		if ($this->mapOptions['heading']) {
			$content .= '<h4>' . $this->mapOptions['heading'] . '</h4>';
		}
		$content .= '<button id="set-map-coords" class="btn btn-outline-primary">Set map coordinates from address</button>';
		$content .= '<div ';
		$content .= 'id="admin-map" ';
		$content .= 'class="admin-google-map" ';
		$content .= 'data-key="' . $this->key . '"';
		$content .= $this->getCSS();
		$content .= '></div>';
		return $content;
	}


	private function getCSS()
	{
		$style = 'style=\'';
		$style .= 'width:' . $this->mapOptions['width'] . ';';
		$style .= 'height:' . $this->mapOptions['height'] . ';';
		$style .= 'margin:' . $this->mapOptions['margin'] . ';\' ';
		return $style;
	}

}
