<?php


namespace Fastrack\Location;


use Fastrack\Property\Property;
use Fastrack\Utilities\ModelUtilities;
use Fastrack\Utilities\Slug;
use SilverStripe\ORM\DataObject;
use SilverStripe\ORM\HasManyList;
use SilverStripe\ORM\ManyManyList;
use SilverStripe\Security\Permission;
use SilverStripe\Security\PermissionProvider;
use SilverStripe\SiteConfig\SiteConfig;
use SilverStripe\Forms\GridField\GridFieldAddNewButton;

/**
 * @method HasManyList SubRegions()
 * @method HasManyList Properties()
 * @property string $Name
 * @property string $Slug
 * @property string $ShortName
 * @property int $SortOrder
 */
class Region extends DataObject implements PermissionProvider
{

	private static $table_name = 'region';

	private static $db = [
		'Name' => 'Varchar',
		'Slug' => 'Varchar',
		'ShortName' => 'Varchar',
		'SortOrder' => 'Int',
	];

	private static $has_one = [
		'SiteConfig' => SiteConfig::class,
	];

	private static $has_many = [
		'SubRegions' => SubRegion::class,
		'Properties' => Property::class,
	];

	private static $default_sort = 'SortOrder';

	private static $translate = [
		'Name',
		'ShortName',
	];

	public function getCMSFields()
	{
		$fields = parent::getCMSFields();
		$fields->removeByName('SiteConfigID');
		$fields->removeByName('SortOrder');
		$propertiesGrid = $fields->dataFieldByName('Properties');
		$propertiesGrid && $propertiesGrid->getConfig()->removeComponentsByType(GridFieldAddNewButton::class);
		ModelUtilities::hideFields($this, $fields);
		return $fields;
	}

	public function onBeforeWrite() {
		$this->Slug = Slug::generateSlug($this->Name, $this->Slug);
		parent::onBeforeWrite();
	}

	public function providePermissions()
	{
		$permisions = [
			'MANAGE_REGIONS' => [
				'name' => 'Manage regions',
				'category' => 'Places',
			],
		];
		$this->extend('updatePermisions', $permisions);
		return $permisions;
	}

	public function canView($member = null)
	{
		return Permission::check(['MANAGE_REGIONS']);
	}

	public function canEdit($member = null)
	{
		return Permission::check(['MANAGE_REGIONS']);
	}

	public function canDelete($member = null)
	{
		return Permission::check(['MANAGE_REGIONS']);
	}

	public function canCreate($member = null, $context = array())
	{
		return Permission::check(['MANAGE_REGIONS']);
	}

}
