<?php


namespace Fastrack\Location;


use Fastrack\Utilities\Slug;
use SilverStripe\ORM\DataObject;
use SilverStripe\Security\Permission;
use SilverStripe\Security\PermissionProvider;

class SubRegion extends DataObject implements PermissionProvider
{

	private static $table_name = 'sub_region';

	private static $db = [
		'Name' => 'Varchar(255)',
		'Slug' => 'Varchar(255)',
	];

	private static $has_one = [
		'Region' => Region::class,
	];

	private static $translate = [
	    'Name',
	];

	public function onBeforeWrite() {
		$this->Slug = Slug::generateSlug($this->Name, $this->Slug);
		parent::onBeforeWrite();
	}

	public function providePermissions()
	{
		$permisions = [
			'MANAGE_SUB_REGIONS' => [
				'name' => 'Manage sub regions',
				'category' => 'Places',
			],
		];
		$this->extend('updatePermisions', $permisions);
		return $permisions;
	}

	public function canView($member = null)
	{
		return Permission::check(['MANAGE_SUB_REGIONS']);
	}

	public function canEdit($member = null)
	{
		return Permission::check(['MANAGE_SUB_REGIONS']);
	}

	public function canDelete($member = null)
	{
		return Permission::check(['MANAGE_SUB_REGIONS']);
	}

	public function canCreate($member = null, $context = array())
	{
		return Permission::check(['MANAGE_SUB_REGIONS']);
	}
}
